Record Class RoutingChoice<Request,Response>
java.lang.Object
java.lang.Record
com.javaaidev.agenticpatterns.routingworkflow.RoutingChoice<Request,Response>
- Type Parameters:
Request- Task input typeResponse- Task output type- Record Components:
name- Name of the routedescription- Description of the routeagent- Task of the route
public record RoutingChoice<Request,Response> (String name, String description, TaskExecutionAgent<Request,Response> agent)
extends Record
A routing choice
-
Constructor Summary
ConstructorsConstructorDescriptionRoutingChoice(String name, String description, TaskExecutionAgent<Request, Response> agent) Creates an instance of aRoutingChoicerecord class. -
Method Summary
Modifier and TypeMethodDescriptionagent()Returns the value of theagentrecord component.Returns the value of thedescriptionrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.name()Returns the value of thenamerecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
RoutingChoice
Creates an instance of aRoutingChoicerecord class.- Parameters:
name- the value for thenamerecord componentdescription- the value for thedescriptionrecord componentagent- the value for theagentrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
name
Returns the value of thenamerecord component.- Returns:
- the value of the
namerecord component
-
description
Returns the value of thedescriptionrecord component.- Returns:
- the value of the
descriptionrecord component
-
agent
Returns the value of theagentrecord component.- Returns:
- the value of the
agentrecord component
-