Record Class RoutingRequest<Request,Response>
java.lang.Object
java.lang.Record
com.javaaidev.agenticpatterns.routingworkflow.RoutingRequest<Request,Response>
- Type Parameters:
Request- Task input typeResponse- Task output type- Record Components:
request- Original task inputchoices- Routing choices, see RoutingChoice
public record RoutingRequest<Request,Response> (@Nullable Request request, List<RoutingChoice<Request,Response>> choices)
extends Record
Routing request
-
Constructor Summary
ConstructorsConstructorDescriptionRoutingRequest(@Nullable Request request, List<RoutingChoice<Request, Response>> choices) Creates an instance of aRoutingRequestrecord class. -
Method Summary
Modifier and TypeMethodDescriptionchoices()Returns the value of thechoicesrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.@Nullable Requestrequest()Returns the value of therequestrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
request
Returns the value of therequestrecord component.- Returns:
- the value of the
requestrecord component
-
choices
Returns the value of thechoicesrecord component.- Returns:
- the value of the
choicesrecord component
-